# Handy Tools

## don't waste your time in common problems

[![Travis Build Status](https://travis-ci.com/katoozi/django-handytools.svg?token=zy2qCzh3h5SeBZfK4QFa&branch=master)](https://travis-ci.com/katoozi/django-handytools)
[![MIT license](http://img.shields.io/badge/license-MIT-brightgreen.svg)](http://opensource.org/licenses/MIT)
[![python](https://img.shields.io/pypi/pyversions/django-handytools.svg)](https://www.djangoproject.com/)
[![django-handytools](https://img.shields.io/pypi/djversions/django-handytools.svg?color=blue&label=django)](https://www.djangoproject.com/)
[![pypi](https://img.shields.io/pypi/dw/django-handytools.svg?label=install)](https://pypi.org/project/django-handytools/)

## Handy Tools For Your Django Project

### provided tools: models, utils, context processors, templates, template tags

## Overview

* Apps: TextPhrases, TextImagePhrase
* Context Processors: text_phrase_simple_cp, text_phrase_language_cp
* Template Tags: google_analytic, single_text_phrase, multi_text_phrase
* Templates: google analytic template
* Supported Languages: en, fr, fa, ja, de, ch, zh-CN, zh-TW

## install

`pip install django-handytools`
> consider --user option
